from playsound import playsound
import os
from DobotEDU import DobotEDU
import base64
from scipy.io.wavfile import write

def to_base64(file_name):  #转化为Base64格式
    with open(file_name,'rb') as f:
        base64_data = base64.b64encode(f.read())
        return base64_data

def asr(file_name):  #语音识别
    audio_data = to_base64(file_name)
    result = speech.asr(audio_data)
    print(result)
    return result

def tts(text):  #语音合成
    audio = speech.synthesis(text,"1")
    with open("audio.mp3",'wb') as f:
        f.write(audio)
    playsound("audio.mp3")
    os.remove("audio.mp3")

def record(file_name,count_down):  #录音
    print("录音开始...")
    myrecording = util.record(count_down)
    print("录音结束...")
    write(file_name, 16000, myrecording)  # 保存为一个WAV文件)
    
# 定义机器人对话函数
def robot_conver():
    session_id = ""
    filename = "audio.wav"
    while True:
        record(filename,4)
        query = asr(filename)
        ret = robot.conversation(query, session_id)
        #print(ret)
        val = 'result' in ret.keys()
        result = ''
        if val == True:
            result = ret['result']['response_list'][0]['action_list'][0]['say']
            print(result)
            tts(result)
            session_id = ret['result']['session_id']
        else:
            print('None')

robot_conver()


from DobotRPC import DobotlinkAdapter, RPCClient, loggers
import inspect


class MagicBoxApi(object):
    def __init__(self, port_name=None):
        self.__dobotlink = DobotlinkAdapter(RPCClient(), is_sync=True)
        self._port_name = port_name

    def get_portname(func):
        def wrapper(self, *args, **kwargs):
            if self._port_name:
                return func(self, self._port_name, *args, **kwargs)
            else:
                return func(self, *args, **kwargs)

        return wrapper

    def search_dobot(self):
        return self.__dobotlink.MagicBox.SearchDobot()

    @get_portname
    def connect_dobot(self, port_name, queue_start=True, is_queued=False):
        return self.__dobotlink.MagicBox.ConnectDobot(portName=port_name,
                                                      queueStart=queue_start,
                                                      isQueued=is_queued)

    @get_portname
    def disconnect_dobot(self,
                         port_name,
                         queue_stop=True,
                         queue_clear=True,
                         is_queued=False):
        return self.__dobotlink.MagicBox.DisconnectDobot(
            portName=port_name,
            queueStop=queue_stop,
            queueClear=queue_clear,
            isQueued=is_queued)

    @get_portname
    def get_devicesn(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetDeviceSN(portName=port_name,
                                                     isQueued=is_queued)

    @get_portname
    def set_devicename(self, port_name, device_name: str, is_queued=False):
        return self.__dobotlink.MagicBox.SetDeviceName(portName=port_name,
                                                       deviceName=device_name,
                                                       isQueued=is_queued)

    @get_portname
    def get_devicename(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetDeviceName(portName=port_name,
                                                       isQueued=is_queued)

    @get_portname
    def get_deviceversion(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetDeviceVersion(portName=port_name,
                                                          isQueued=is_queued)

    @get_portname
    def set_devicewithl(self,
                        port_name,
                        enable=True,
                        version=1,
                        is_queued=False):
        return self.__dobotlink.MagicBox.SetDeviceWithL(portName=port_name,
                                                        enable=enable,
                                                        version=version,
                                                        isQueued=is_queued)

    @get_portname
    def get_devicewithl(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetDeviceWithL(portName=port_name,
                                                        isQueued=is_queued)

    @get_portname
    def get_devicetime(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetDeviceTime(portName=port_name,
                                                       isQueued=is_queued)

    @get_portname
    def get_deviceid(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetDeviceID(portName=port_name,
                                                     isQueued=is_queued)

    @get_portname
    def get_productname(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetProductName(portName=port_name,
                                                        isQueued=is_queued)

    @get_portname
    def set_oleddisplay(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.SetOLEDDisplay(portName=port_name,
                                                        isQueued=is_queued)

    @get_portname
    def queuedcmd_start(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.QueuedCmdStart(portName=port_name,
                                                        isQueued=is_queued)

    @get_portname
    def queuedcmd_stop(self, port_name, force_stop=False, is_queued=False):
        return self.__dobotlink.MagicBox.QueuedCmdStop(portName=port_name,
                                                       forceStop=force_stop,
                                                       isQueued=is_queued)

    @get_portname
    def queuedcmd_clear(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.QueuedCmdClear(portName=port_name,
                                                        isQueued=is_queued)

    @get_portname
    def queuedcmd_startdownload(self,
                                port_name,
                                total_loop: int,
                                lineper_loop: int,
                                is_queued=False):
        return self.__dobotlink.MagicBox.QueuedCmdStartDownload(
            portName=port_name,
            totalLoop=total_loop,
            linePerLoop=lineper_loop,
            isQueued=is_queued)

    @get_portname
    def queuedcmd_stopdownload(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.QueuedCmdStopDownload(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def get_queuedcmd_currentindex(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetQueuedCmdCurrentIndex(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def get_queuedcmd_leftspace(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetQueuedCmdLeftSpace(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_servo_angle(self,
                        port_name,
                        index: int,
                        set_value: float,
                        is_queued=False):
        return self.__dobotlink.MagicBox.SetServoAngle(portName=port_name,
                                                       index=index,
                                                       value=set_value,
                                                       isQueued=is_queued)

    @get_portname
    def get_servo_angle(self, port_name, index: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetServoAngle(portName=port_name,
                                                       index=index,
                                                       isQueued=is_queued)

    @get_portname
    def set_lspeed_ratio(self,
                         port_name,
                         set_type: int,
                         set_value: int,
                         is_queued=False):
        return self.__dobotlink.MagicBox.SetLSpeedRatio(portName=port_name,
                                                        type=set_type,
                                                        value=set_value,
                                                        isQueued=is_queued)

    @get_portname
    def get_lspeed_ratio(self, port_name, get_type: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetLSpeedRatio(portName=port_name,
                                                        type=get_type,
                                                        isQueued=is_queued)

    @get_portname
    def get_posel(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetPoseL(portName=port_name,
                                                  isQueued=is_queued)

    @get_portname
    def set_ptpwith_lcmd(self,
                         port_name,
                         set_l: float,
                         is_queued=True,
                         iswait_forfinish=True,
                         timeout=30000):
        return self.__dobotlink.MagicBox.SetPTPWithLCmd(
            portName=port_name,
            l=set_l,
            isQueued=is_queued,
            isWaitForFinish=iswait_forfinish,
            timeout=timeout)

    @get_portname
    def set_iomultiplexing(self,
                           port_name,
                           port: int,
                           multiplex: int,
                           is_queued=False):
        return self.__dobotlink.MagicBox.SetIOMultiplexing(portName=port_name,
                                                           port=port,
                                                           multiplex=multiplex,
                                                           isQueued=is_queued)

    @get_portname
    def get_iomultiplexing(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetIOMultiplexing(portName=port_name,
                                                           port=port,
                                                           isQueued=is_queued)

    @get_portname
    def set_iodo(self, port_name, port: int, level: int, is_queued=False):
        return self.__dobotlink.MagicBox.SetIODO(portName=port_name,
                                                 port=port,
                                                 level=level,
                                                 isQueued=is_queued)

    @get_portname
    def get_iodo(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetIODO(portName=port_name,
                                                 port=port,
                                                 isQueued=is_queued)

    @get_portname
    def set_iopwm(self,
                  port_name,
                  port: int,
                  frequency: float,
                  duty_cycle: float,
                  is_queued=False):
        return self.__dobotlink.MagicBox.SetIOPWM(portName=port_name,
                                                  port=port,
                                                  frequency=frequency,
                                                  dutyCycle=duty_cycle,
                                                  isQueued=is_queued)

    @get_portname
    def get_iopwm(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetIOPWM(portName=port_name,
                                                  port=port,
                                                  isQueued=is_queued)

    @get_portname
    def get_iodi(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetIODI(portName=port_name,
                                                 port=port,
                                                 isQueued=is_queued)

    @get_portname
    def get_ioadc(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetIOADC(portName=port_name,
                                                  port=port,
                                                  isQueued=is_queued)

    @get_portname
    def set_emotor(self,
                   port_name,
                   index: int,
                   enable: bool,
                   speed,
                   is_queued=False):
        return self.__dobotlink.MagicBox.SetEMotor(portName=port_name,
                                                   index=index,
                                                   enable=enable,
                                                   speed=speed,
                                                   isQueued=is_queued)

    @get_portname
    def set_emotors(self,
                    port_name,
                    index: int,
                    enable: bool,
                    speed,
                    distance,
                    is_queued=False):
        return self.__dobotlink.MagicBox.SetEMotorS(portName=port_name,
                                                    index=index,
                                                    enable=enable,
                                                    speed=speed,
                                                    distance=distance,
                                                    isQueued=is_queued)

    @get_portname
    def set_color_sensor(self,
                         port_name,
                         port: int,
                         enable: bool,
                         version: int,
                         is_queued=False):
        return self.__dobotlink.MagicBox.SetColorSensor(portName=port_name,
                                                        port=port - 1,
                                                        enable=enable,
                                                        version=version,
                                                        isQueued=is_queued)

    @get_portname
    def get_color_sensor(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetColorSensor(portName=port_name,
                                                        isQueued=is_queued)

    @get_portname
    def set_infrared_sensor(self,
                            port_name,
                            port: int,
                            enable: bool,
                            version: int,
                            is_queued=False):
        return self.__dobotlink.MagicBox.SetInfraredSensor(portName=port_name,
                                                           port=port - 1,
                                                           enable=enable,
                                                           version=version,
                                                           isQueued=is_queued)

    @get_portname
    def get_infrared_sensor(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.MagicBox.GetInfraredSensor(portName=port_name,
                                                           port=port - 1,
                                                           isQueued=is_queued)

    @get_portname
    def set_homecmd(self,
                    port_name,
                    is_queued=True,
                    iswait_forfinish=True,
                    time_out=25000):
        return self.__dobotlink.MagicBox.SetHOMECmd(
            portName=port_name,
            isQueued=is_queued,
            isWaitForFinish=iswait_forfinish,
            timeout=time_out)

    @get_portname
    def set_jogl_params(self,
                        port_name,
                        velocity,
                        acceleration,
                        is_queued=False):
        return self.__dobotlink.MagicBox.SetJOGLParams(
            portName=port_name,
            velocity=velocity,
            acceleration=acceleration,
            isQueued=is_queued)

    @get_portname
    def get_jogl_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicBox.GetJOGLParams(portName=port_name,
                                                       isQueued=is_queued)

    @get_portname
    def set_jogcmd(self, port_name, is_joint: bool, cmd: int, is_queued=True):
        return self.__dobotlink.MagicBox.SetJOGCmd(portName=port_name,
                                                   isJoint=is_joint,
                                                   cmd=cmd,
                                                   isQueued=is_queued)



from DobotRPC import RPCClient
import asyncio
from typing import List, Any

IP = '127.0.0.1'
PORT = '10001'


class RPCAdapter(object):
    def __init__(self, ip, port):
        self.__rpc_client = RPCClient(ip, port)
        loop = asyncio.get_event_loop()
        loop.run_until_complete(self.__rpc_client.wait_for_connected())

    def __getattr__(self, func_name: str) -> Any:
        def send_wrapper(**params) -> Any:
            method = func_name
            fut = self.__rpc_client.send(method, params)
            loop = asyncio.get_event_loop()
            return loop.run_until_complete(fut)

        return send_wrapper


class Pyimageom(object):
    def __init__(self):
        self._r_client = RPCAdapter(ip=IP, port=PORT)

    def image_cut(self, img_base64: str):
        return self._r_client.image_cut(img_base64=img_base64)

    def feature_image_classify(self, img_base64s: List[Any], lables: List[int],
                               class_num: int, flag: int):
        return self._r_client.feature_image_classify(img_base64s=img_base64s,
                                                     lables=lables,
                                                     class_num=class_num,
                                                     flag=flag)

    def feature_image_group(self, img_base64: str):
        return self._r_client.feature_image_group(img_base64=img_base64)

    def find_chessboard_corners(self, img_base64: str):
        return self._r_client.find_chessboard_corners(img_base64=img_base64)

    def color_image_cut(self, img_base64: str):
        return self._r_client.color_image_cut(img_base64=img_base64)

    def color_image_classify(self, img_base64s: List[Any], lables: List[int],
                             class_num: int, flag: int):
        return self._r_client.color_image_classify(img_base64s=img_base64s,
                                                   lables=lables,
                                                   class_num=class_num,
                                                   flag=flag)

    def color_image_group(self, img_base64: str):
        return self._r_client.color_image_group(img_base64=img_base64)

    def set_background(self, img_base64: str):
        return self._r_client.set_background(img_base64=img_base64)



from DobotRPC import DobotlinkAdapter, RPCClient, loggers
import inspect


class MagicianGoApi(object):
    def __init__(self, port_name=None):
        self.__dobotlink = DobotlinkAdapter(RPCClient(), is_sync=True)
        self._port_name = port_name

    def get_portname(func):
        def wrapper(self, *args, **kwargs):
            if self._port_name:
                return func(self, self._port_name, *args, **kwargs)
            else:
                return func(self, *args, **kwargs)

        return wrapper

    @get_portname
    def set_running_mode(self, port_name, mode):
        return self.__dobotlink.MagicianGO.SetRunningMode(portName=port_name,
                                                          runningMode=mode)

    @get_portname
    def set_move_speed_direct(self, port_name, direction, speed):
        return self.__dobotlink.MagicianGO.SetMoveSpeedDirect(
            portName=port_name, dir=direction, speed=speed)

    @get_portname
    def set_move_speed(self, port_name, x, y, r):
        return self.__dobotlink.MagicianGO.SetMoveSpeed(portName=port_name,
                                                        x=x,
                                                        y=y,
                                                        r=r)

    @get_portname
    def set_rotate(self, port_name, r, Vr):
        return self.__dobotlink.MagicianGO.SetRotate(portName=port_name,
                                                     r=r,
                                                     Vr=Vr,
                                                     isQueued=True,
                                                     isWaitForFinish=True,
                                                     timeout=604800000)

    @get_portname
    def set_move_dist(self, port_name, x, y, Vx, Vy):
        return self.__dobotlink.MagicianGO.SetMoveDist(portName=port_name,
                                                       x=x,
                                                       y=y,
                                                       Vx=Vx,
                                                       Vy=Vy,
                                                       isQueued=True,
                                                       isWaitForFinish=True,
                                                       timeout=604800000)

    @get_portname
    def set_move_pos(self, port_name, x, y, s):
        return self.__dobotlink.MagicianGO.SetMovePos(portName=port_name,
                                                      x=x,
                                                      y=y,
                                                      s=s,
                                                      isQueued=True,
                                                      isWaitForFinish=True,
                                                      timeout=604800000)

    @get_portname
    def set_arc_rad(self, port_name, velocity, radius, angle, mode):
        return self.__dobotlink.MagicianGO.SetArcRad(portName=port_name,
                                                     velocity=velocity,
                                                     radius=radius,
                                                     angle=angle,
                                                     mode=mode,
                                                     isQueued=True,
                                                     isWaitForFinish=True,
                                                     timeout=604800000)

    @get_portname
    def set_arc_cent(self, port_name, velocity, x, y, angle, mode):
        return self.__dobotlink.MagicianGO.SetArcCent(portName=port_name,
                                                      velocity=velocity,
                                                      x=x,
                                                      y=y,
                                                      angle=angle,
                                                      mode=mode,
                                                      isQueued=True,
                                                      isWaitForFinish=True,
                                                      timeout=604800000)

    @get_portname
    def set_coord_closed_loop(self, port_name, isEnable, angle):
        return self.__dobotlink.MagicianGO.SetCoordClosedLoop(
            portName=port_name, isEnable=isEnable, angle=angle)

    @get_portname
    def set_increment_closed_loop(self, port_name, x, y, angle):
        return self.__dobotlink.MagicianGO.SetIncrementClosedLoop(
            portName=port_name,
            x=x,
            y=y,
            angle=angle,
            isQueued=True,
            isWaitForFinish=True,
            timeout=604800000)

    @get_portname
    def set_rgb_light(self, port_name, number, effect, r, g, b, cycle, counts):
        return self.__dobotlink.MagicianGO.SetLightRGB(portName=port_name,
                                                       number=number,
                                                       effect=effect,
                                                       r=r,
                                                       g=g,
                                                       b=b,
                                                       cycle=cycle,
                                                       counts=counts)

    @get_portname
    def set_buzzer_sound(self, port_name, index, tone, beat):
        return self.__dobotlink.MagicianGO.SetBuzzerSound(portName=port_name,
                                                          index=index,
                                                          tone=tone,
                                                          beat=beat)

    @get_portname
    def get_ultrasonic_data(self, port_name):
        return self.__dobotlink.MagicianGO.GetUltrasoundData(
            portName=port_name)

    @get_portname
    def get_odometer_data(self, port_name):
        return self.__dobotlink.MagicianGO.GetSpeedometer(portName=port_name)

    @get_portname
    def get_power_voltage(self, port_name):
        return self.__dobotlink.MagicianGO.GetBatteryVoltage(
            portName=port_name)

    @get_portname
    def get_imu_angle(self, port_name):
        return self.__dobotlink.MagicianGO.GetImuAngle(portName=port_name)

    @get_portname
    def get_imu_speed(self, port_name):
        return self.__dobotlink.MagicianGO.GetImuSpeed(portName=port_name)

    @get_portname
    def set_auto_trace(self, port_name, trace):
        return self.__dobotlink.MagicianGO.SetTraceAuto(portName=port_name,
                                                        isTrace=trace)

    @get_portname
    def set_trace_speed(self, port_name, speed):
        return self.__dobotlink.MagicianGO.SetTraceSpeed(portName=port_name,
                                                         speed=speed)

    @get_portname
    def set_trace_pid(self, port_name, p, i, d):
        return self.__dobotlink.MagicianGO.SetTracePid(portName=port_name,
                                                       p=p,
                                                       i=i,
                                                       d=d)

    @get_portname
    def get_trace_angle(self, port_name):
        return self.__dobotlink.MagicianGO.GetCarCameraAngle(
            portName=port_name)

    @get_portname
    def get_arm_camera_obj(self, port_name):
        return self.__dobotlink.MagicianGO.GetArmCameraObj(portName=port_name)

    @get_portname
    def get_car_camera_obj(self, port_name):
        return self.__dobotlink.MagicianGO.GetCarCameraObj(portName=port_name)

    @get_portname
    def get_arm_camera_tag(self, port_name):
        return self.__dobotlink.MagicianGO.GetArmCameraTag(portName=port_name)



from DobotRPC import DobotlinkAdapter, RPCClient


class M1Api(object):
    def __init__(self):
        self.__dobotlink = DobotlinkAdapter(RPCClient(), is_sync=True)

    def search_dobot(self):
        return self.__dobotlink.M1.SearchDobot()

    def connect_dobot(self, port_name, queue_start=True, is_queued=False):
        return self.__dobotlink.M1.ConnectDobot(portName=port_name,
                                                queueStart=queue_start,
                                                isQueued=is_queued)

    def disconnect_dobot(self,
                         port_name,
                         queue_stop=True,
                         queue_clear=True,
                         is_queued=False):
        return self.__dobotlink.M1.DisconnectDobot(portName=port_name,
                                                   queueStop=queue_stop,
                                                   queueClear=queue_clear,
                                                   isQueued=is_queued)

    def get_devicesn(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetDeviceSN(portName=port_name,
                                               isQueued=is_queued)

    def set_devicename(self, port_name, device_name: str, is_queued=False):
        return self.__dobotlink.M1.SetDeviceName(portName=port_name,
                                                 deviceName=device_name,
                                                 isQueued=is_queued)

    def get_devicename(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetDeviceName(portName=port_name,
                                                 isQueued=is_queued)

    def get_deviceversion(self, port_name, get_type: int, is_queued=False):
        return self.__dobotlink.M1.GetDeviceVersion(portName=port_name,
                                                    type=get_type,
                                                    isQueued=is_queued)

    def get_hardware_version(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetHardwareVersion(portName=port_name,
                                                      isQueued=is_queued)

    def queuedcmd_start(self, port_name, is_queued=False):
        return self.__dobotlink.M1.QueuedCmdStart(portName=port_name,
                                                  isQueued=is_queued)

    def queuedcmd_stop(self, port_name, force_stop=False, is_queued=False):
        return self.__dobotlink.M1.QueuedCmdStop(portName=port_name,
                                                 forceStop=force_stop,
                                                 isQueued=is_queued)

    def queuedcmd_clear(self, port_name, is_queued=False):
        return self.__dobotlink.M1.QueuedCmdClear(portName=port_name,
                                                  isQueued=is_queued)

    def queuedcmd_startdownload(self,
                                port_name,
                                total_loop: int,
                                lineper_loop: int,
                                is_queued=False):
        return self.__dobotlink.M1.QueuedCmdStartDownload(
            portName=port_name,
            totalLoop=total_loop,
            linePerLoop=lineper_loop,
            isQueued=is_queued)

    def queuedcmd_stopdownload(self, port_name, is_queued=False):
        return self.__dobotlink.M1.QueuedCmdStopDownload(portName=port_name,
                                                         isQueued=is_queued)

    def get_queuedcmd_currentindex(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetQueuedCmdCurrentIndex(portName=port_name,
                                                            isQueued=is_queued)

    def get_queuedcmd_leftspace(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetQueuedCmdLeftSpace(portName=port_name,
                                                         isQueued=is_queued)

    def get_pose(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetPose(portName=port_name,
                                           isQueued=is_queued)

    def reset_pose(self,
                   port_name,
                   front_angle1: float,
                   front_angle2: float,
                   is_queued=False):
        return self.__dobotlink.M1.ResetPose(portName=port_name,
                                             frontAngle1=front_angle1,
                                             frontAngle2=front_angle2,
                                             isQueued=is_queued)

    def set_usercoordinate(self,
                           port_name,
                           x: float,
                           y: float,
                           z: float,
                           r: float,
                           is_queued=False):
        return self.__dobotlink.M1.SetUserCoordinate(portName=port_name,
                                                     x=x,
                                                     y=y,
                                                     z=z,
                                                     r=r,
                                                     isQueued=is_queued)

    def get_usercoordinate(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetUserCoordinate(portName=port_name,
                                                     isQueued=is_queued)

    def set_toolcoordinate(self,
                           port_name,
                           x: float,
                           y: float,
                           z: float,
                           r: float,
                           is_queued=False):
        return self.__dobotlink.M1.SetToolCoordinate(portName=port_name,
                                                     x=x,
                                                     y=y,
                                                     z=z,
                                                     r=r,
                                                     isQueued=is_queued)

    def get_toolcoordinate(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetToolCoordinate(portName=port_name,
                                                     isQueued=is_queued)

    def get_alarms_state(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetAlarmsState(portName=port_name,
                                                  isQueued=is_queued)

    def clear_allalarms_state(self, port_name, is_queued=False):
        return self.__dobotlink.M1.ClearAllAlarmsState(portName=port_name,
                                                       isQueued=is_queued)

    def get_run_state(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetRunState(portName=port_name,
                                               isQueued=is_queued)

    def set_homecmd(self,
                    port_name,
                    is_resetpars=False,
                    is_queued=True,
                    is_wait=True,
                    time_out=25000):
        return self.__dobotlink.M1.SetHOMECmd(portName=port_name,
                                              isResetPars=is_resetpars,
                                              isQueued=is_queued,
                                              isWaitForFinish=is_wait,
                                              timeout=time_out)

    def set_home_initialpos(self, port_name, is_queued=False):
        return self.__dobotlink.M1.SetHOMEInitialPos(portName=port_name,
                                                     isQueued=is_queued)

    def set_hhttrig_mode(self, port_name, mode: int, is_queued=False):
        return self.__dobotlink.M1.SetHHTTrigMode(portName=port_name,
                                                  mode=mode,
                                                  isQueued=is_queued)

    def get_hhttrig_mode(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetHHTTrigMode(portName=port_name,
                                                  isQueued=is_queued)

    def set_hhttrig_output_enabled(self,
                                   port_name,
                                   enable: bool,
                                   is_queued=False):
        return self.__dobotlink.M1.SetHHTTrigOutputEnabled(portName=port_name,
                                                           enable=enable,
                                                           isQueued=is_queued)

    def get_hhttrig_output_enabled(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetHHTTrigOutputEnabled(portName=port_name,
                                                           isQueued=is_queued)

    def get_hhttrig_output(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetHHTTrigOutput(portName=port_name,
                                                    isQueued=is_queued)

    def set_servo_power(self, port_name, on: bool, is_queued=False):
        return self.__dobotlink.M1.SetServoPower(portName=port_name,
                                                 on=on,
                                                 isQueued=is_queued)

    def set_endeffector_params(self,
                               port_name,
                               x_offset: float,
                               y_offset: float,
                               z_offset: float,
                               is_queued=False):
        return self.__dobotlink.M1.SetEndEffectorParams(portName=port_name,
                                                        xOffset=x_offset,
                                                        yOffset=y_offset,
                                                        zOffset=z_offset,
                                                        isQueued=is_queued)

    def get_endeffector_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetEndEffectorParams(portName=port_name,
                                                        isQueued=is_queued)

    def set_endeffector_laser(self,
                              port_name,
                              enable: bool,
                              on: bool,
                              is_queued=False):
        return self.__dobotlink.M1.SetEndEffectorLaser(portName=port_name,
                                                       enable=enable,
                                                       on=on,
                                                       isQueued=is_queued)

    def get_endeffector_laser(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetEndEffectorLaser(portName=port_name,
                                                       isQueued=is_queued)

    def set_endeffector_suctioncup(self,
                                   port_name,
                                   enable: bool,
                                   on: bool,
                                   is_queued=False):
        return self.__dobotlink.M1.SetEndEffectorSuctionCup(portName=port_name,
                                                            enable=enable,
                                                            on=on,
                                                            isQueued=is_queued)

    def get_endeffector_suctioncup(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetEndEffectorSuctionCup(portName=port_name,
                                                            isQueued=is_queued)

    def set_endeffector_gripper(self,
                                port_name,
                                enable: bool,
                                on: bool,
                                is_queued=False):
        return self.__dobotlink.M1.SetEndEffectorGripper(portName=port_name,
                                                         enable=enable,
                                                         on=on,
                                                         isQueued=is_queued)

    def get_endeffector_gripper(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetEndEffectorGripper(portName=port_name,
                                                         isQueued=is_queued)

    def set_jogjoint_params(self,
                            port_name,
                            velocity,
                            acceleration,
                            is_queued=False):
        return self.__dobotlink.M1.SetJOGJointParams(portName=port_name,
                                                     velocity=velocity,
                                                     acceleration=acceleration,
                                                     isQueued=is_queued)

    def get_jogjoint_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetJOGJointParams(portName=port_name,
                                                     isQueued=is_queued)

    def set_jogcoordinate_params(self,
                                 port_name,
                                 velocity,
                                 acceleration,
                                 is_queued=False):
        return self.__dobotlink.M1.SetJOGCoordinateParams(
            portName=port_name,
            velocity=velocity,
            acceleration=acceleration,
            isQueued=is_queued)

    def get_jogcoordinate_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetJOGCoordinateParams(portName=port_name,
                                                          isQueued=is_queued)

    def set_jogcommon_params(self,
                             port_name,
                             velocity_ratio: float,
                             acceleration_ratio: float,
                             is_queued=False):
        return self.__dobotlink.M1.SetJOGCommonParams(
            portName=port_name,
            velocityRatio=velocity_ratio,
            accelerationRatio=acceleration_ratio,
            isQueued=is_queued)

    def get_jogcommon_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetJOGCommonParams(portName=port_name,
                                                      isQueued=is_queued)

    def set_jogcmd(self, port_name, is_joint: bool, cmd: int, is_queued=True):
        return self.__dobotlink.M1.SetJOGCmd(portName=port_name,
                                             isJoint=is_joint,
                                             cmd=cmd,
                                             isQueued=is_queued)

    def set_inchmode(self, port_name, mode: int, is_queued=False):
        return self.__dobotlink.M1.SetInchMode(portName=port_name,
                                               mode=mode,
                                               isQueued=is_queued)

    def get_inchmode(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetInchMode(portName=port_name,
                                               isQueued=is_queued)

    def set_inchparam(self,
                      port_name,
                      distance_mm: float,
                      distance_ang: float,
                      is_queued=False):
        return self.__dobotlink.M1.SetInchParam(portName=port_name,
                                                distanceMM=distance_mm,
                                                distanceANG=distance_ang,
                                                isQueued=is_queued)

    def get_inchparam(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetInchParam(portName=port_name,
                                                isQueued=is_queued)

    def set_ptpcmd(self,
                   port_name,
                   ptp_mode: int,
                   x: float,
                   y: float,
                   z: float,
                   r: float,
                   is_queued=True,
                   is_wait=True):
        return self.__dobotlink.M1.SetPTPCmd(portName=port_name,
                                             ptpMode=ptp_mode,
                                             x=x,
                                             y=y,
                                             z=z,
                                             r=r,
                                             isQueued=is_queued,
                                             isWaitForFinish=is_wait)

    def set_ptpjoint_param(self,
                           port_name,
                           velocity,
                           acceleration,
                           is_queued=False):
        return self.__dobotlink.M1.SetPTPJointParams(portName=port_name,
                                                     velocity=velocity,
                                                     acceleration=acceleration,
                                                     isQueued=is_queued)

    def get_ptpjoint_param(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetPTPJointParams(portName=port_name,
                                                     isQueued=is_queued)

    def set_ptpcoordinate_params(self,
                                 port_name,
                                 xyz_velocity: float,
                                 r_velocity: float,
                                 xyz_acceleration: float,
                                 r_acceleration: float,
                                 is_queued=False):
        return self.__dobotlink.M1.SetPTPCoordinateParams(
            portName=port_name,
            xyzVelocity=xyz_velocity,
            rVelocity=r_velocity,
            xyzAcceleration=xyz_acceleration,
            rAcceleration=r_acceleration,
            isQueued=is_queued)

    def get_ptpcoordinate_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetPTPCoordinateParams(portName=port_name,
                                                          isQueued=is_queued)

    def set_ptpjump_params(self,
                           port_name,
                           isusing_zlimit: bool,
                           z_limit: float,
                           jump_height: float,
                           is_queued=False):
        return self.__dobotlink.M1.SetPTPJumpParams(
            portName=port_name,
            isUsingZLimit=isusing_zlimit,
            zLimit=z_limit,
            jumpHeight=jump_height,
            isQueued=is_queued)

    def get_ptpjump_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetPTPJumpParams(portName=port_name,
                                                    isQueued=is_queued)

    def set_ptpcommon_params(self,
                             port_name,
                             velocity_ratio: float,
                             acceleration_ratio: float,
                             is_queued=False):
        return self.__dobotlink.M1.SetPTPCommonParams(
            portName=port_name,
            velocityRatio=velocity_ratio,
            accelerationRatio=acceleration_ratio,
            isQueued=is_queued)

    def get_ptpcommon_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetPTPCommonParams(portName=port_name,
                                                      isQueued=is_queued)

    def set_motivation_mode(self, port_name, mode: int, is_queued=False):
        return self.__dobotlink.M1.SetMotivationMode(portName=port_name,
                                                     mode=mode,
                                                     isQueued=is_queued)

    def get_motivation_mode(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetMotivationMode(portName=port_name,
                                                     isQueued=is_queued)

    def set_motivate_cmd(self,
                         port_name,
                         q1: float,
                         q2: float,
                         dq1: float,
                         dq2: float,
                         ddq1: float,
                         ddq2: float,
                         is_queued=True,
                         is_wait=True,
                         time_out=10000):
        return self.__dobotlink.M1.SetMotivateCmd(
            portName=port_name,
            q1=q1,
            q2=q2,
            dq1=dq1,
            dq2=dq2,
            ddq1=ddq1,
            ddq2=ddq2,
            isQueued=is_queued,
            isWaitForFinish=is_wait,
            timeout=time_out)

    def set_motivate_zcmd(self,
                          port_name,
                          qz: float,
                          dqz: float,
                          ddqz: float,
                          is_queued=True,
                          is_wait=True):
        return self.__dobotlink.M1.SetMotivateZCmd(
            portName=port_name,
            qz=qz,
            dqz=dqz,
            ddqz=ddqz,
            isQueued=is_queued,
            isWaitForFinish=is_wait)

    def get_trajectory(self,
                       port_name,
                       count_max: int,
                       index: int,
                       is_queued=False):
        return self.__dobotlink.M1.GetTrajectory(portName=port_name,
                                                 countMax=count_max,
                                                 index=index,
                                                 isQueued=is_queued)

    def set_iodo(self, port_name, port: int, level: int, is_queued=False):
        return self.__dobotlink.M1.SetIODO(portName=port_name,
                                           port=port,
                                           level=level,
                                           isQueued=is_queued)

    def get_iodo(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.M1.GetIODO(portName=port_name,
                                           port=port,
                                           isQueued=is_queued)

    def get_iodi(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.M1.GetIODI(portName=port_name,
                                           port=port,
                                           isQueued=is_queued)

    def get_ioadc(self, port_name, port: int, is_queued=False):
        return self.__dobotlink.M1.GetIOADC(portName=port_name,
                                            port=port,
                                            isQueued=is_queued)

    def set_cpparams(self,
                     port_name,
                     target_acc: float,
                     junction_vel: float,
                     isreal_timetrack: bool,
                     acc=None,
                     period=None,
                     is_queued=False):
        return self.__dobotlink.M1.SetCPParams(
            portName=port_name,
            targetAcc=target_acc,
            junctionVel=junction_vel,
            isRealTimeTrack=isreal_timetrack,
            acc=acc,
            period=period,
            isQueued=is_queued)

    def get_cpparams(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetCPParams(portName=port_name,
                                               isQueued=is_queued)

    def set_cpcmd(self,
                  port_name,
                  cp_mode: int,
                  x: float,
                  y: float,
                  z: float,
                  power: float,
                  is_queued=True):
        return self.__dobotlink.M1.SetCPCmd(portName=port_name,
                                            cpMode=cp_mode,
                                            x=x,
                                            y=y,
                                            z=z,
                                            power=power,
                                            isQueued=is_queued)

    def set_cplecmd(self,
                    port_name,
                    cp_mode: int,
                    x: float,
                    y: float,
                    z: float,
                    power: float,
                    is_queued=True):
        return self.__dobotlink.M1.SetCPLECmd(portName=port_name,
                                              cpMode=cp_mode,
                                              x=x,
                                              y=y,
                                              z=z,
                                              power=power,
                                              isQueued=is_queued)

    def set_arcparams(self,
                      port_name,
                      xyz_velocity: float,
                      r_velocity: float,
                      xyz_acceleration: float,
                      r_acceleration: float,
                      is_queued=False):
        return self.__dobotlink.M1.SetARCParams(
            portName=port_name,
            xyzVelocity=xyz_velocity,
            rVelocity=r_velocity,
            xyzAcceleration=xyz_acceleration,
            rAcceleration=r_acceleration,
            isQueued=is_queued)

    def get_arcparams(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetARCParams(portName=port_name,
                                                isQueued=is_queued)

    def set_arccmd(self, port_name, cir_point, to_point, is_queued=True):
        return self.__dobotlink.M1.SetARCCmd(portName=port_name,
                                             cirPoint=cir_point,
                                             toPoint=to_point,
                                             isQueued=is_queued)

    def set_arcpocmd(self,
                     port_name,
                     cir_point,
                     to_point,
                     arc_po,
                     is_queued=True):
        return self.__dobotlink.M1.SetARCPOCmd(portName=port_name,
                                               cirPoint=cir_point,
                                               toPoint=to_point,
                                               arcPO=arc_po,
                                               isQueued=is_queued)

    def set_circle_cmd(self,
                       port_name,
                       cir_point,
                       to_point,
                       count: int,
                       is_queued=True,
                       is_wait=True,
                       time_out=60000):
        return self.__dobotlink.M1.SetCircleCmd(
            portName=port_name,
            cirPoint=cir_point,
            toPoint=to_point,
            count=count,
            isQueued=is_queued,
            isWaitForFinish=is_wait,
            timeout=time_out)

    def set_circle_pocmd(self,
                         port_name,
                         cir_point,
                         to_point,
                         count: int,
                         circle_po,
                         is_queued=True):
        return self.__dobotlink.M1.SetCirclePOCmd(portName=port_name,
                                                  cirPoint=cir_point,
                                                  toPoint=to_point,
                                                  count=count,
                                                  circlePO=circle_po,
                                                  isQueued=is_queued)

    def set_arm_orientation(self,
                            port_name,
                            arm_orientation: int,
                            is_queued=False):
        return self.__dobotlink.M1.SetArmOrientation(
            portName=port_name,
            armOrientation=arm_orientation,
            isQueued=is_queued)

    def get_arm_orientation(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetArmOrientation(portName=port_name,
                                                     isQueued=is_queued)

    def set_waitcmd(self, port_name, delay: int, is_queued=True):
        return self.__dobotlink.M1.SetWAITCmd(portName=port_name,
                                              delay=delay,
                                              timeout=delay + 500,
                                              isQueued=is_queued)

    def set_safemode_enabled(self, port_name, enable: bool, is_queued=False):
        return self.__dobotlink.M1.SetSafeModeEnabled(portName=port_name,
                                                      enable=enable,
                                                      isQueued=is_queued)

    def get_safemode_enabled(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetSafeModeEnabled(portName=port_name,
                                                      isQueued=is_queued)

    def set_collision_threshold(self,
                                port_name,
                                tor_diffj1: float,
                                tor_diffj2: float,
                                tor_diffj3: float,
                                tor_diffj4: float,
                                is_queued=False):
        return self.__dobotlink.M1.SetCollisionThreshold(portName=port_name,
                                                         torDiffJ1=tor_diffj1,
                                                         torDiffJ2=tor_diffj2,
                                                         torDiffJ3=tor_diffj3,
                                                         torDiffJ4=tor_diffj4,
                                                         isQueued=is_queued)

    def get_collision_threshold(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetCollisionThreshold(portName=port_name,
                                                         isQueued=is_queued)

    def set_basicdynamic_params(self,
                                port_name,
                                zz1: float,
                                fs1: float,
                                fv1: float,
                                zz2: float,
                                mx2: float,
                                my2: float,
                                ia2: float,
                                fs2: float,
                                fv2: float,
                                is_queued=False):
        return self.__dobotlink.M1.SetBasicDynamicParams(portName=port_name,
                                                         ZZ1=zz1,
                                                         FS1=fs1,
                                                         FV1=fv1,
                                                         ZZ2=zz2,
                                                         MX2=mx2,
                                                         MY2=my2,
                                                         IA2=ia2,
                                                         FS2=fs2,
                                                         FV2=fv2,
                                                         isQueued=is_queued)

    def get_basicdynamic_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetBasicDynamicParams(portName=port_name,
                                                         isQueued=is_queued)

    def set_load_params(self, port_name, load_params: float, is_queued=False):
        return self.__dobotlink.M1.SetLoadParams(portName=port_name,
                                                 loadParams=load_params,
                                                 isQueued=is_queued)

    def get_load_params(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetLoadParams(portName=port_name,
                                                 isQueued=is_queued)

    def set_safestrategy(self, port_name, strategy: int, is_queued=False):
        return self.__dobotlink.M1.SetSafeStrategy(portName=port_name,
                                                   strategy=strategy,
                                                   isQueued=is_queued)

    def get_safestrategy(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetSafeStrategy(portName=port_name,
                                                   isQueued=is_queued)

    def set_safeguard_mode(self, port_name, mode: int, is_queued=False):
        return self.__dobotlink.M1.SetSafeGuardMode(portName=port_name,
                                                    mode=mode,
                                                    isQueued=is_queued)

    def get_safeguard_mode(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetSafeGuardMode(portName=port_name,
                                                    isQueued=is_queued)

    def get_safeguard_status(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetSafeGuardStatus(portName=port_name,
                                                      isQueued=is_queued)

    def set_lanport_config(self,
                           port_name,
                           addr: str,
                           mask: str,
                           gateway: str,
                           dns: str,
                           isdhcp: bool,
                           is_queued=False):
        return self.__dobotlink.M1.SetLanPortConfig(portName=port_name,
                                                    addr=addr,
                                                    mask=mask,
                                                    gateway=gateway,
                                                    dns=dns,
                                                    isdhcp=isdhcp,
                                                    isQueued=is_queued)

    def get_lanport_config(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetLanPortConfig(portName=port_name,
                                                    isQueued=is_queued)

    def set_firmware_reboot(self, port_name, is_queued=False):
        return self.__dobotlink.M1.SetFirmwareReboot(portName=port_name,
                                                     isQueued=is_queued)

    def set_firmware_notifym4mode(self, port_name, mode: int, is_queued=False):
        return self.__dobotlink.M1.SetFirmwareNotifyM4Mode(portName=port_name,
                                                           mode=mode,
                                                           isQueued=is_queued)

    def get_firmware_notifym4mode(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetFirmwareNotifyM4Mode(portName=port_name,
                                                           isQueued=is_queued)

    def set_feed_forward(self, port_name, value: int, is_queued=False):
        return self.__dobotlink.M1.SetFeedforward(portName=port_name,
                                                  value=value,
                                                  isQueued=is_queued)

    def get_feed_forward(self, port_name, is_queued=False):
        return self.__dobotlink.M1.GetFeedforward(portName=port_name,
                                                  isQueued=is_queued)



from .Magician import MagicianApi
from .MagicBox import MagicBoxApi
from .MagicianGo import MagicianGoApi
from .Lite import LiteApi
from .M1 import M1Api

__all__ = ("MagicianApi", "MagicBoxApi", "MagicianGoApi", "LiteApi", "M1Api")



from DobotRPC import DobotlinkAdapter, RPCClient, loggers
import inspect


class LiteApi(object):
    def __init__(self, port_name=None):
        self.__dobotlink = DobotlinkAdapter(RPCClient(), is_sync=True)
        self._port_name = port_name

    def get_portname(func):
        def wrapper(self, *args, **kwargs):
            if self._port_name:
                return func(self, self._port_name, *args, **kwargs)
            else:
                return func(self, *args, **kwargs)

        return wrapper

    def search_dobot(self):
        return self.__dobotlink.MagicianLite.SearchDobot()

    @get_portname
    def connect_dobot(self, port_name, queue_start=True, is_queued=False):
        return self.__dobotlink.MagicianLite.ConnectDobot(
            portName=port_name, queueStart=queue_start, isQueued=is_queued)

    @get_portname
    def disconnect_dobot(self,
                         port_name,
                         queue_stop=True,
                         queue_clear=True,
                         is_queued=False):
        return self.__dobotlink.MagicianLite.DisconnectDobot(
            portName=port_name,
            queueStop=queue_stop,
            queueClear=queue_clear,
            isQueued=is_queued)

    @get_portname
    def get_devicesn(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetDeviceSN(portName=port_name,
                                                         isQueued=is_queued)

    @get_portname
    def set_devicename(self, port_name, device_name: str, is_queued=False):
        return self.__dobotlink.MagicianLite.SetDeviceName(
            portName=port_name, deviceName=device_name, isQueued=is_queued)

    @get_portname
    def get_devicename(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetDeviceName(portName=port_name,
                                                           isQueued=is_queued)

    @get_portname
    def get_deviceversion(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetDeviceVersion(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def get_devicetime(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetDeviceTime(portName=port_name,
                                                           isQueued=is_queued)

    @get_portname
    def get_deviceid(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetDeviceID(portName=port_name,
                                                         isQueued=is_queued)

    @get_portname
    def get_productname(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetProductName(portName=port_name,
                                                            isQueued=is_queued)

    @get_portname
    def queuedcmd_start(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.QueuedCmdStart(portName=port_name,
                                                            isQueued=is_queued)

    @get_portname
    def queuedcmd_stop(self, port_name, force_stop=False, is_queued=False):
        return self.__dobotlink.MagicianLite.QueuedCmdStop(
            portName=port_name, forceStop=force_stop, isQueued=is_queued)

    @get_portname
    def queuedcmd_clear(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.QueuedCmdClear(portName=port_name,
                                                            isQueued=is_queued)

    @get_portname
    def queuedcmd_startdownload(self,
                                port_name,
                                total_loop: int,
                                lineper_loop: int,
                                is_queued=False):
        return self.__dobotlink.MagicianLite.QueuedCmdStartDownload(
            portName=port_name,
            totalLoop=total_loop,
            linePerLoop=lineper_loop,
            isQueued=is_queued)

    @get_portname
    def queuedcmd_stopdownload(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.QueuedCmdStopDownload(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def get_queuedcmd_currentindex(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetQueuedCmdCurrentIndex(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def get_queuedcmd_leftspace(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetQueuedCmdLeftSpace(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_armspeed_ratio(self,
                           port_name,
                           set_type: int,
                           set_value: int,
                           is_queued=False):
        return self.__dobotlink.MagicianLite.SetArmSpeedRatio(
            portName=port_name,
            type=set_type,
            value=set_value,
            isQueued=is_queued)

    @get_portname
    def get_armspeed_ratio(self, port_name, get_type: int, is_queued=False):
        return self.__dobotlink.MagicianLite.GetArmSpeedRatio(
            portName=port_name, type=get_type, isQueued=is_queued)

    @get_portname
    def get_pose(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetPose(portName=port_name,
                                                     isQueued=is_queued)

    @get_portname
    def reset_pose(self,
                   port_name,
                   manual_enable: bool,
                   rear_armangle=None,
                   front_armangle=None,
                   is_queued=False):
        return self.__dobotlink.MagicianLite.ResetPose(
            portName=port_name,
            manualEnable=manual_enable,
            rearArmAngle=rear_armangle,
            frontArmAngle=front_armangle,
            isQueued=is_queued)

    @get_portname
    def check_poselimit(self,
                        port_name,
                        is_joint: bool,
                        x: float,
                        y: float,
                        z: float,
                        r: float,
                        is_queued=False):
        return self.__dobotlink.MagicianLite.CheckPoseLimit(portName=port_name,
                                                            isJoint=is_joint,
                                                            x=x,
                                                            y=y,
                                                            z=z,
                                                            r=r,
                                                            isQueued=is_queued)

    @get_portname
    def get_alarms_state(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetAlarmsState(portName=port_name,
                                                            isQueued=is_queued)

    @get_portname
    def clear_allalarms_state(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.ClearAllAlarmsState(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_homeparams(self,
                       port_name,
                       x: float,
                       y: float,
                       z: float,
                       r: float,
                       is_queued=False):
        return self.__dobotlink.MagicianLite.SetHOMEParams(portName=port_name,
                                                           x=x,
                                                           y=y,
                                                           z=z,
                                                           r=r,
                                                           isQueued=is_queued)

    @get_portname
    def get_homeparams(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetHOMEParams(portName=port_name,
                                                           isQueued=is_queued)

    @get_portname
    def set_homecmd(self,
                    port_name,
                    is_wait=True,
                    time_out=25000,
                    is_queued=True):
        return self.__dobotlink.MagicianLite.SetHOMECmd(
            portName=port_name,
            isQueued=is_queued,
            isWaitForFinish=is_wait,
            timeout=time_out)

    @get_portname
    def set_endeffector_params(self,
                               port_name,
                               x_offset: float,
                               y_offset: float,
                               z_offset: float,
                               is_queued=False):
        return self.__dobotlink.MagicianLite.SetEndEffectorParams(
            portName=port_name,
            xOffset=x_offset,
            yOffset=y_offset,
            zOffset=z_offset,
            isQueued=is_queued)

    @get_portname
    def get_endeffector_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetEndEffectorParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_endeffector_type(self, port_name, set_type: int, is_queued=False):
        return self.__dobotlink.MagicianLite.SetEndEffectorType(
            portName=port_name, type=set_type, isQueued=is_queued)

    @get_portname
    def get_endeffector_type(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetEndEffectorType(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_endeffector_suctioncup(self,
                                   port_name,
                                   enable: bool,
                                   on: bool,
                                   is_queued=False):
        return self.__dobotlink.MagicianLite.SetEndEffectorSuctionCup(
            portName=port_name, enable=enable, on=on, isQueued=is_queued)

    @get_portname
    def get_endeffector_suctioncup(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetEndEffectorSuctionCup(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_endeffector_gripper(self,
                                port_name,
                                enable: bool,
                                on: bool,
                                is_queued=False):
        return self.__dobotlink.MagicianLite.SetEndEffectorGripper(
            portName=port_name, enable=enable, on=on, isQueued=is_queued)

    @get_portname
    def get_endeffector_gripper(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetEndEffectorGripper(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_jogjoint_params(self,
                            port_name,
                            velocity,
                            acceleration,
                            is_queued=False):
        return self.__dobotlink.MagicianLite.SetJOGJointParams(
            portName=port_name,
            velocity=velocity,
            acceleration=acceleration,
            isQueued=is_queued)

    @get_portname
    def get_jogjoint_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetJOGJointParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_jogcoordinate_params(self,
                                 port_name,
                                 velocity,
                                 acceleration,
                                 is_queued=False):
        return self.__dobotlink.MagicianLite.SetJOGCoordinateParams(
            portName=port_name,
            velocity=velocity,
            acceleration=acceleration,
            isQueued=is_queued)

    @get_portname
    def get_jogcoordinate_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetJOGCoordinateParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_jogcommon_params(self,
                             port_name,
                             velocity_ratio: float,
                             acceleration_ratio: float,
                             is_queued=False):
        return self.__dobotlink.MagicianLite.SetJOGCommonParams(
            portName=port_name,
            velocityRatio=velocity_ratio,
            accelerationRatio=acceleration_ratio,
            isQueued=is_queued)

    @get_portname
    def get_jogcommon_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetJOGCommonParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_jogcmd(self, port_name, is_joint: bool, cmd: int, is_queued=True):
        return self.__dobotlink.MagicianLite.SetJOGCmd(portName=port_name,
                                                       isJoint=is_joint,
                                                       cmd=cmd,
                                                       isQueued=is_queued)

    @get_portname
    def set_ptpcmd(self,
                   port_name,
                   ptp_mode: int,
                   x: float,
                   y: float,
                   z: float,
                   r: float,
                   is_queued=True,
                   is_wait=True):
        return self.__dobotlink.MagicianLite.SetPTPCmd(portName=port_name,
                                                       ptpMode=ptp_mode,
                                                       x=x,
                                                       y=y,
                                                       z=z,
                                                       r=r,
                                                       isQueued=is_queued,
                                                       isWaitForFinish=is_wait)

    @get_portname
    def set_rcmd(self,
                 port_name,
                 r: int,
                 is_queued=True,
                 is_wait=True,
                 time_out=5000):
        return self.__dobotlink.MagicianLite.SetRCmd(portName=port_name,
                                                     r=r,
                                                     isQueued=is_queued,
                                                     isWaitForFinish=is_wait,
                                                     timeout=time_out)

    @get_portname
    def set_ptpjoint_param(self,
                           port_name,
                           velocity,
                           acceleration,
                           is_queued=False):
        return self.__dobotlink.MagicianLite.SetPTPJointParams(
            portName=port_name,
            velocity=velocity,
            acceleration=acceleration,
            isQueued=is_queued)

    @get_portname
    def get_ptpjoint_param(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetPTPJointParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_ptpcoordinate_params(self,
                                 port_name,
                                 xyz_velocity: float,
                                 r_velocity: float,
                                 xyz_acceleration: float,
                                 r_acceleration: float,
                                 is_queued=False):
        return self.__dobotlink.MagicianLite.SetPTPCoordinateParams(
            portName=port_name,
            xyzVelocity=xyz_velocity,
            rVelocity=r_velocity,
            xyzAcceleration=xyz_acceleration,
            rAcceleration=r_acceleration,
            isQueued=is_queued)

    @get_portname
    def get_ptpcoordinate_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetPTPCoordinateParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_ptpjump_params(self,
                           port_name,
                           z_limit: float,
                           jump_height: float,
                           is_queued=False):
        return self.__dobotlink.MagicianLite.SetPTPJumpParams(
            portName=port_name,
            zLimit=z_limit,
            jumpHeight=jump_height,
            isQueued=is_queued)

    @get_portname
    def get_ptpjump_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetPTPJumpParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_ptpcommon_params(self,
                             port_name,
                             velocity_ratio: float,
                             acceleration_ratio: float,
                             is_queued=False):
        return self.__dobotlink.MagicianLite.SetPTPCommonParams(
            portName=port_name,
            velocityRatio=velocity_ratio,
            accelerationRatio=acceleration_ratio,
            isQueued=is_queued)

    @get_portname
    def get_ptpcommon_params(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetPTPCommonParams(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_loststep_value(self, port_name, value: float):
        return self.__dobotlink.MagicianLite.SetLostStepValue(
            portName=port_name, value=value)

    @get_portname
    def set_loststep_cmd(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.SetLostStepCmd(portName=port_name,
                                                            isQueued=is_queued)

    @get_portname
    def set_collision_check(self,
                            port_name,
                            enable: bool,
                            thre_shold: float,
                            is_queued=False):
        return self.__dobotlink.MagicianLite.SetCollisionCheck(
            portName=port_name,
            enable=enable,
            threshold=thre_shold,
            isQueued=is_queued)

    @get_portname
    def get_collision_check(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetCollisionCheck(
            portName=port_name, isQueued=is_queued)

    @get_portname
    def set_cpparams(self,
                     port_name,
                     target_acc: float,
                     junction_vel: float,
                     isreal_timetrack: bool,
                     acc=None,
                     period=None,
                     is_queued=False):
        return self.__dobotlink.MagicianLite.SetCPParams(
            portName=port_name,
            targetAcc=target_acc,
            junctionVel=junction_vel,
            isRealTimeTrack=isreal_timetrack,
            acc=acc,
            period=period,
            isQueued=is_queued)

    @get_portname
    def get_cpparams(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetCPParams(portName=port_name,
                                                         isQueued=is_queued)

    @get_portname
    def set_cpcmd(self,
                  port_name,
                  cp_mode: int,
                  x: float,
                  y: float,
                  z: float,
                  power: float,
                  is_queued=True):
        return self.__dobotlink.MagicianLite.SetCPCmd(portName=port_name,
                                                      cpMode=cp_mode,
                                                      x=x,
                                                      y=y,
                                                      z=z,
                                                      power=power,
                                                      isQueued=is_queued)

    @get_portname
    def set_cplecmd(self,
                    port_name,
                    cp_mode: int,
                    x: float,
                    y: float,
                    z: float,
                    power: float,
                    is_queued=True):
        return self.__dobotlink.MagicianLite.SetCPLECmd(portName=port_name,
                                                        cpMode=cp_mode,
                                                        x=x,
                                                        y=y,
                                                        z=z,
                                                        power=power,
                                                        isQueued=is_queued)

    @get_portname
    def set_arcparams(self,
                      port_name,
                      xyz_velocity: float,
                      r_velocity: float,
                      xyz_acceleration: float,
                      r_acceleration: float,
                      is_queued=False):
        return self.__dobotlink.MagicianLite.SetARCParams(
            portName=port_name,
            xyzVelocity=xyz_velocity,
            rVelocity=r_velocity,
            xyzAcceleration=xyz_acceleration,
            rAcceleration=r_acceleration,
            isQueued=is_queued)

    @get_portname
    def get_arcparams(self, port_name, is_queued=False):
        return self.__dobotlink.MagicianLite.GetARCParams(portName=port_name,
                                                          isQueued=is_queued)

    @get_portname
    def set_arccmd(self, port_name, cir_point, to_point, is_queued=True):
        return self.__dobotlink.MagicianLite.SetARCCmd(portName=port_name,
                                                       cirPoint=cir_point,
                                                       toPoint=to_point,
                                                       isQueued=is_queued)



import os
from setuptools import setup, find_packages  # 这个包没有的可以pip一下

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "README.rst")) as f:
    DESCRIPTION = f.read()

setup(
    name="DobotEDU",  # 这里是pip项目发布的名称
    version="1.4.4",  # 版本号，数值大的会优先被pip
    keywords=["DobotEDU", "Dobotlink"],
    description="Dobotlink communication module",
    long_description=DESCRIPTION,
    long_description_content_type="text/markdown",
    license="Apache Licence",

    author="songlijun",
    author_email="songlijun@dobot.cc",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=["opencv-python", "sounddevice", "soundfile",
                      "DobotRPC", "requests", "playsound", "scipy"]
)
